

set -ex



pip check
jupyter lab --version
jlpm --version
jupyter-lab --help
jupyter-labextension --help
jupyter labextension list
jupyter lab licenses
jupyter lab path
jupyter server extension list
jupyter server extension list 1>server_extensions 2>&1
cat server_extensions | rg "jupyterlab.*4\.0\.11.*OK"
jupyter lab build --dev-build=False --minimize=False
jupyter lab clean
python -m pytest -vv --pyargs jupyterlab
exit 0
