# Copyright (c) Jupyter Development Team.
# Distributed under the terms of the Modified BSD License.


def _jupyter_labextension_paths():
    return [{"src": "labextension", "dest": "test-hyphens-underscore"}]
